==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/cdn/kotlin/inputs/GetRoutePlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.cdn.kotlin.inputs

import com.pulumi.azurenative.cdn.inputs.GetRoutePlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property endpointName Name of the endpoint under the profile which is unique globally.
 * @property profileName Name of the Azure Front Door Standard or Azure Front Door Premium profile which is unique within the resource group.
 * @property resourceGroupName Name of the Resource group within the Azure subscription.
 * @property routeName Name of the routing rule.
 */
public data class GetRoutePlainArgs(
    public val endpointName: String,
    public val profileName: String,
    public val resourceGroupName: String,
    public val routeName: String,
) : ConvertibleToJava<com.pulumi.azurenative.cdn.inputs.GetRoutePlainArgs> {
    override fun toJava(): com.pulumi.azurenative.cdn.inputs.GetRoutePlainArgs =
        com.pulumi.azurenative.cdn.inputs.GetRoutePlainArgs.builder()
            .endpointName(endpointName.let({ args0 -> args0 }))
            .profileName(profileName.let({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 }))
            .routeName(routeName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [GetRoutePlainArgs].
 */
@PulumiTagMarker
public class GetRoutePlainArgsBuilder internal constructor() {
    private var endpointName: String? = null

    private var profileName: String? = null

    private var resourceGroupName: String? = null

    private var routeName: String? = null

    /**
     * @param value Name of the endpoint under the profile which is unique globally.
     */
    @JvmName("gglsngippvqyykgp")
    public suspend fun endpointName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.endpointName = mapped
    }

    /**
     * @param value Name of the Azure Front Door Standard or Azure Front Door Premium profile which is unique within the resource group.
     */
    @JvmName("ekpsspnrjduwwmqd")
    public suspend fun profileName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.profileName = mapped
    }

    /**
     * @param value Name of the Resource group within the Azure subscription.
     */
    @JvmName("rmlqvxgdonjrupoq")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    /**
     * @param value Name of the routing rule.
     */
    @JvmName("cfiiheyldlrvmbsr")
    public suspend fun routeName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.routeName = mapped
    }

    internal fun build(): GetRoutePlainArgs = GetRoutePlainArgs(
        endpointName = endpointName ?: throw PulumiNullFieldException("endpointName"),
        profileName = profileName ?: throw PulumiNullFieldException("profileName"),
        resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
        routeName = routeName ?: throw PulumiNullFieldException("routeName"),
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/cdn/kotlin/inputs/GetRoutePlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.cdn.kotlin.inputs

import com.pulumi.azurenative.cdn.inputs.GetRoutePlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property endpointName Name of the endpoint under the profile which is unique globally.
 * @property profileName Name of the Azure Front Door Standard or Azure Front Door Premium profile which is unique within the resource group.
 * @property resourceGroupName Name of the Resource group within the Azure subscription.
 * @property routeName Name of the routing rule.
 */
public data class GetRoutePlainArgs(
    public val endpointName: String,
    public val profileName: String,
    public val resourceGroupName: String,
    public val routeName: String,
) : ConvertibleToJava<com.pulumi.azurenative.cdn.inputs.GetRoutePlainArgs> {
    override fun toJava(): com.pulumi.azurenative.cdn.inputs.GetRoutePlainArgs =
        com.pulumi.azurenative.cdn.inputs.GetRoutePlainArgs.builder()
            .endpointName(endpointName.let({ args0 -> args0 }))
            .profileName(profileName.let({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 }))
            .routeName(routeName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [GetRoutePlainArgs].
 */
@PulumiTagMarker
public class GetRoutePlainArgsBuilder internal constructor() {
    private var endpointName: String? = null

    private var profileName: String? = null

    private var resourceGroupName: String? = null

    private var routeName: String? = null

    /**
     * @param value Name of the endpoint under the profile which is unique globally.
     */
    @JvmName("eilickkhcbglpfbi")
    public suspend fun endpointName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.endpointName = mapped
    }

    /**
     * @param value Name of the Azure Front Door Standard or Azure Front Door Premium profile which is unique within the resource group.
     */
    @JvmName("frgihigewtvpfndv")
    public suspend fun profileName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.profileName = mapped
    }

    /**
     * @param value Name of the Resource group within the Azure subscription.
     */
    @JvmName("rupcgumgjuprchaw")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    /**
     * @param value Name of the routing rule.
     */
    @JvmName("vftklrdmltueceoj")
    public suspend fun routeName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.routeName = mapped
    }

    internal fun build(): GetRoutePlainArgs = GetRoutePlainArgs(
        endpointName = endpointName ?: throw PulumiNullFieldException("endpointName"),
        profileName = profileName ?: throw PulumiNullFieldException("profileName"),
        resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
        routeName = routeName ?: throw PulumiNullFieldException("routeName"),
    )
}
